Developer Guide
===============

This section of the documentation details the general development goals of Antelop. In particular, we discuss the structure of the repository, our security model, the structure of the codebases, and the structure of the Nextflow pipelines. This is so that future collaborators can be quickly brought up to speed on the project.

.. toctree::
   :maxdepth: 1
   :titlesonly:

   repo
   security
   pipelines
